@@ -12,6 +12,6 @@ class DiscreteInput(BaseRegister):
     def update_state(self):
         """Read Register."""
         res = self._connection.client.read_discrete_inputs(
-            self.addr, slave=self._connection.slave)
+            self.addr, device_id=self._connection.device_id)
         if not res.isError():
             self.state = res.bits[0]
